static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";
/*
 * Copyright (C) 1992, 1993, 1994, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 *
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
#include <stdio.h>
#include <malloc.h>
#include <assert.h>

#include "XmgfMalloc.h"

#include <Xm/Xm.h>
#include <MotifUtils.h>

#define MAX_STR_LEN 100


XmString
Str2MotStr(CharString)
char *CharString;
{
	XmString MotifString = NULL;
	MotifString = XmStringCreateLtoR(CharString++, charset);
	assert(MotifString);
	return (MotifString);
}

char *
MotStr2Str(MotifString)
XmString *MotifString;
{
	char *CharString;
	CharString = (char *) XmgfMalloc(MAX_STR_LEN * sizeof(char));
	assert(CharString);
	XmStringGetLtoR(*MotifString, XmSTRING_DEFAULT_CHARSET, &CharString);
	return CharString;
}
